Introduction to graphflow
=========================

This Python package provides numerical routines for graph flow analysis, particularly:

* PageRank
* Linear System of Resistance
* Non-linear System of Resistance
* HITS (Hyperlink-Induced Topic Search)

Author: Kwan-Yuet Ho (LinkedIn_, ResearchGate_, Twitter_)

Home: :doc:`index`

.. _LinkedIn: https://www.linkedin.com/in/kwan-yuet-ho-19882530
.. _ResearchGate: https://www.researchgate.net/profile/Kwan-yuet_Ho
.. _Twitter: https://twitter.com/stephenhky
